==> kubernetes-model-1.0.52-sources.jar: annotations/io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class GCEPersistentDiskVolumeSourceBuilder extends GCEPersistentDiskVolumeSourceFluentImpl<GCEPersistentDiskVolumeSourceBuilder> implements VisitableBuilder<GCEPersistentDiskVolumeSource,GCEPersistentDiskVolumeSourceBuilder>{

    GCEPersistentDiskVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public GCEPersistentDiskVolumeSourceBuilder(){
            this(true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(Boolean validationEnabled){
            this(new GCEPersistentDiskVolumeSource(), validationEnabled);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new GCEPersistentDiskVolumeSource(), validationEnabled);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent,GCEPersistentDiskVolumeSource instance){
            this(fluent, instance, true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent,GCEPersistentDiskVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFsType(instance.getFsType()); 
            fluent.withPartition(instance.getPartition()); 
            fluent.withPdName(instance.getPdName()); 
            fluent.withReadOnly(instance.getReadOnly()); 
            this.validationEnabled = validationEnabled; 
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSource instance){
            this(instance,true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFsType(instance.getFsType()); 
            this.withPartition(instance.getPartition()); 
            this.withPdName(instance.getPdName()); 
            this.withReadOnly(instance.getReadOnly()); 
            this.validationEnabled = validationEnabled; 
    }

    public GCEPersistentDiskVolumeSource build(){
            GCEPersistentDiskVolumeSource buildable = new GCEPersistentDiskVolumeSource(fluent.getFsType(),fluent.getPartition(),fluent.getPdName(),fluent.isReadOnly());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            GCEPersistentDiskVolumeSourceBuilder that = (GCEPersistentDiskVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class GCEPersistentDiskVolumeSourceBuilder extends GCEPersistentDiskVolumeSourceFluentImpl<GCEPersistentDiskVolumeSourceBuilder> implements VisitableBuilder<GCEPersistentDiskVolumeSource,GCEPersistentDiskVolumeSourceBuilder>{

    GCEPersistentDiskVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public GCEPersistentDiskVolumeSourceBuilder(){
            this(true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(Boolean validationEnabled){
            this(new GCEPersistentDiskVolumeSource(), validationEnabled);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new GCEPersistentDiskVolumeSource(), validationEnabled);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent,GCEPersistentDiskVolumeSource instance){
            this(fluent, instance, true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSourceFluent<?> fluent,GCEPersistentDiskVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFsType(instance.getFsType()); 
            fluent.withPartition(instance.getPartition()); 
            fluent.withPdName(instance.getPdName()); 
            fluent.withReadOnly(instance.getReadOnly()); 
            this.validationEnabled = validationEnabled; 
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSource instance){
            this(instance,true);
    }
    public GCEPersistentDiskVolumeSourceBuilder(GCEPersistentDiskVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFsType(instance.getFsType()); 
            this.withPartition(instance.getPartition()); 
            this.withPdName(instance.getPdName()); 
            this.withReadOnly(instance.getReadOnly()); 
            this.validationEnabled = validationEnabled; 
    }

    public GCEPersistentDiskVolumeSource build(){
            GCEPersistentDiskVolumeSource buildable = new GCEPersistentDiskVolumeSource(fluent.getFsType(),fluent.getPartition(),fluent.getPdName(),fluent.isReadOnly());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            GCEPersistentDiskVolumeSourceBuilder that = (GCEPersistentDiskVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
